/*
textplain.c

Designed to read anything readmail considers "text/plain" on stdin and
write it back on stdout with each line preceded by --- so it can be
identified. The characters < and > are encoded so the output is
suitable for inclusion in a web page between <pre> and </pre> tags.
*/

#include <stdio.h>
#include <stdlib.h>

static void printhtml(char *b)
{
	int c, n = 0;

	while ((c = *b++)) {
		n++;
		if (n > 80) {
			fputs("\n---", stdout);
			n = 0;
		}
		switch (c) {
		case ' ':
			if (n > 66 && strlen(b) > 10) {
				fputs("\n---", stdout);
				n = 0;
			} else {
				putchar(c);
			}
			break;
		case '<':
			fputs("&lt;", stdout);
			break;
		case '>':
			fputs("&gt;", stdout);
			break;
		case '"':
			fputs("&quot;", stdout);
			break;
		case '&':
			fputs("&amp;", stdout);
			break;
		default:
			putchar(c);
		}
	}
}

int main(int argc, char **argv)
{
	char b[1000];
	char *p = getenv("PRETAGS");
	char *q = getenv("QUOTE");
	printf("\n");	/* necessary, don't know why */
	if (p && p[0]) printf("---<pre>\n");
	while (fgets(b, sizeof b, stdin)) {
		fputs("---", stdout);
		if (q) printhtml(q);
		printhtml(b);
	}
	if (p && p[0]) printf("---</pre>\n");
	return EXIT_SUCCESS;
}

